@@ -26,9 +26,7 @@ expit <- function(x) {
 # CRAN release questions
 release_questions <- function() {
   c(
-    "Have you turned off local tests in test-AIC, test-anova, test-augment,
-        test-coef, test-fitted, test-generics, test-glances, test-loocv,
-        test-predict, test-spautor, test-splm, and test-tidy?",
+    "Have you turned off local tests or implemented skip_on_cran()?",
     "Have you changed version numbers in DESCRIPTION, CITATION, and README?",
     "Have you run pkgdown::build_site() and committed?"
   )
